@@ -35,7 +35,7 @@ class ApproverInfo(AbstractModel):
 0：企业
 1：个人
 3：企业静默签署
-注：类型为3（企业静默签署）时，此接口会默认完成该签署方的签署。
+注：类型为3（企业静默签署）时，此接口会默认完成该签署方的签署。静默签署仅进行盖章操作，不能自动签名。
         :type ApproverType: int
         :param ApproverName: 本环节需要操作人的名字
         :type ApproverName: str
@@ -60,6 +60,12 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         :type VerifyChannel: list of str
         :param PreReadTime: 合同的强制预览时间：3~300s，未指定则按合同页数计算
         :type PreReadTime: int
+        :param UserId: 签署人userId，非企微场景不使用此字段
+        :type UserId: str
+        :param ApproverSource: 签署人用户来源,企微侧用户请传入：WEWORKAPP
+        :type ApproverSource: str
+        :param CustomApproverTag: 客户自定义签署人标识，64位长度，保证唯一，非企微场景不使用此字段
+        :type CustomApproverTag: str
         """
         self.ApproverType = None
         self.ApproverName = None
@@ -72,6 +78,9 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         self.ApproverRole = None
         self.VerifyChannel = None
         self.PreReadTime = None
+        self.UserId = None
+        self.ApproverSource = None
+        self.CustomApproverTag = None
 
 
     def _deserialize(self, params):
@@ -91,6 +100,9 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         self.ApproverRole = params.get("ApproverRole")
         self.VerifyChannel = params.get("VerifyChannel")
         self.PreReadTime = params.get("PreReadTime")
+        self.UserId = params.get("UserId")
+        self.ApproverSource = params.get("ApproverSource")
+        self.CustomApproverTag = params.get("CustomApproverTag")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -647,6 +659,62 @@ class CreateDocumentResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateFlowApproversRequest(AbstractModel):
+    """CreateFlowApprovers请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Operator: 调用方用户信息，userId 必填
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param FlowId: 签署流程编号
+        :type FlowId: str
+        :param Approvers: 补充签署人信息
+        :type Approvers: list of FillApproverInfo
+        """
+        self.Operator = None
+        self.FlowId = None
+        self.Approvers = None
+
+
+    def _deserialize(self, params):
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        self.FlowId = params.get("FlowId")
+        if params.get("Approvers") is not None:
+            self.Approvers = []
+            for item in params.get("Approvers"):
+                obj = FillApproverInfo()
+                obj._deserialize(item)
+                self.Approvers.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateFlowApproversResponse(AbstractModel):
+    """CreateFlowApprovers返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class CreateFlowByFilesRequest(AbstractModel):
     """CreateFlowByFiles请求参数结构体
 
@@ -671,6 +739,8 @@ class CreateFlowByFilesRequest(AbstractModel):
         :type CcInfos: list of CcInfo
         :param NeedPreview: 是否需要预览，true：预览模式，false：非预览（默认）；
 预览链接有效期300秒；
+
+注：如果使用“预览模式”，出参会返回合同预览链接 PreviewUrl，不会正式发起合同，且出参不会返回签署流程编号 FlowId；如果使用“非预览”，则会正常返回签署流程编号 FlowId，不会生成合同预览链接 PreviewUrl。
         :type NeedPreview: bool
         :param FlowDescription: 签署流程描述,最大长度1000个字符
         :type FlowDescription: str
@@ -684,8 +754,8 @@ false：有序签
         :type Unordered: bool
         :param CustomShowMap: 合同显示的页卡模板，说明：只支持{合同名称}, {发起方企业}, {发起方姓名}, {签署方N企业}, {签署方N姓名}，且N不能超过签署人的数量，N从1开始
         :type CustomShowMap: str
-        :param NeedSignReview: 发起方企业的签署人进行签署操作是否需要企业内部审批。
-若设置为true,审核结果需通过接口 CreateFlowSignReview 通知电子签，审核通过后，发起方企业签署人方可进行签署操作，否则会阻塞其签署操作。
+        :param NeedSignReview: 发起方企业的签署人进行签署操作是否需要企业内部审批。使用此功能需要发起方企业有参与签署。
+若设置为true，审核结果需通过接口 CreateFlowSignReview 通知电子签，审核通过后，发起方企业签署人方可进行签署操作，否则会阻塞其签署操作。
 
 注：企业可以通过此功能与企业内部的审批流程进行关联，支持手动、静默签署合同。
         :type NeedSignReview: bool
@@ -758,9 +828,13 @@ class CreateFlowByFilesResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param FlowId: 签署流程编号
+        :param FlowId: 签署流程编号。
+
+注：如入参 是否需要预览 NeedPreview 设置为 true，不会正式发起合同，此处不会有值返回；如入参 是否需要预览 NeedPreview 设置为 false，此处会正常返回签署流程编号 FlowId。
         :type FlowId: str
-        :param PreviewUrl: 合同预览链接
+        :param PreviewUrl: 合同预览链接。
+
+注：如入参 是否需要预览 NeedPreview 设置为 true，会开启“预览模式”，此处会返回预览链接；如入参 是否需要预览 NeedPreview 设置为 false，此处不会有值返回。
 注意：此字段可能返回 null，表示取不到有效值。
         :type PreviewUrl: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1348,6 +1422,62 @@ class DescribeFlowBriefsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeFlowInfoRequest(AbstractModel):
+    """DescribeFlowInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FlowIds: 需要查询的流程ID列表，限制最大100个
+        :type FlowIds: list of str
+        :param Operator: 调用方用户信息
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        """
+        self.FlowIds = None
+        self.Operator = None
+
+
+    def _deserialize(self, params):
+        self.FlowIds = params.get("FlowIds")
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeFlowInfoResponse(AbstractModel):
+    """DescribeFlowInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FlowDetailInfos: 签署流程信息
+        :type FlowDetailInfos: list of FlowDetailInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.FlowDetailInfos = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("FlowDetailInfos") is not None:
+            self.FlowDetailInfos = []
+            for item in params.get("FlowDetailInfos"):
+                obj = FlowDetailInfo()
+                obj._deserialize(item)
+                self.FlowDetailInfos.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeFlowTemplatesRequest(AbstractModel):
     """DescribeFlowTemplates请求参数结构体
 
@@ -1545,6 +1675,40 @@ class FileUrl(AbstractModel):
         
 
 
+class FillApproverInfo(AbstractModel):
+    """补充签署人信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RecipientId: 签署人签署Id
+        :type RecipientId: str
+        :param ApproverSource: 签署人来源
+WEWORKAPP: 企业微信
+        :type ApproverSource: str
+        :param CustomUserId: 企业自定义账号Id
+WEWORKAPP场景下指企业自有应用获取企微明文的userid
+        :type CustomUserId: str
+        """
+        self.RecipientId = None
+        self.ApproverSource = None
+        self.CustomUserId = None
+
+
+    def _deserialize(self, params):
+        self.RecipientId = params.get("RecipientId")
+        self.ApproverSource = params.get("ApproverSource")
+        self.CustomUserId = params.get("CustomUserId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Filter(AbstractModel):
     """查询过滤条件
 
@@ -1573,6 +1737,95 @@ class Filter(AbstractModel):
         
 
 
+class FlowApproverDetail(AbstractModel):
+    """签署人详情信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ApproveMessage: 签署人信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApproveMessage: str
+        :param ApproveName: 签署人名字
+        :type ApproveName: str
+        :param ApproveStatus: 签署人的状态
+0：还没有发起
+1：流程中 没有开始处理
+2：待处理
+3：签署态
+4：拒绝态
+5：过期没人处理
+6：取消态
+7：还没有预发起
+8：待填写
+9：因为各种原因而终止
+        :type ApproveStatus: int
+        :param ReceiptId: 模板配置时候的签署人id,与控件绑定
+        :type ReceiptId: str
+        :param CustomUserId: 客户自定义userId
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CustomUserId: str
+        :param Mobile: 签署人手机号
+        :type Mobile: str
+        :param SignOrder: 签署顺序
+        :type SignOrder: int
+        :param ApproveTime: 签署人签署时间
+        :type ApproveTime: int
+        :param ApproveType: 参与者类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApproveType: str
+        :param ApproverSource: 签署人侧用户来源
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApproverSource: str
+        :param CustomApproverTag: 客户自定义签署人标识
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CustomApproverTag: str
+        :param OrganizationId: 签署人企业Id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OrganizationId: str
+        :param OrganizationName: 签署人企业名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OrganizationName: str
+        """
+        self.ApproveMessage = None
+        self.ApproveName = None
+        self.ApproveStatus = None
+        self.ReceiptId = None
+        self.CustomUserId = None
+        self.Mobile = None
+        self.SignOrder = None
+        self.ApproveTime = None
+        self.ApproveType = None
+        self.ApproverSource = None
+        self.CustomApproverTag = None
+        self.OrganizationId = None
+        self.OrganizationName = None
+
+
+    def _deserialize(self, params):
+        self.ApproveMessage = params.get("ApproveMessage")
+        self.ApproveName = params.get("ApproveName")
+        self.ApproveStatus = params.get("ApproveStatus")
+        self.ReceiptId = params.get("ReceiptId")
+        self.CustomUserId = params.get("CustomUserId")
+        self.Mobile = params.get("Mobile")
+        self.SignOrder = params.get("SignOrder")
+        self.ApproveTime = params.get("ApproveTime")
+        self.ApproveType = params.get("ApproveType")
+        self.ApproverSource = params.get("ApproverSource")
+        self.CustomApproverTag = params.get("CustomApproverTag")
+        self.OrganizationId = params.get("OrganizationId")
+        self.OrganizationName = params.get("OrganizationName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class FlowBrief(AbstractModel):
     """流程信息摘要
 
@@ -1647,7 +1900,7 @@ class FlowCreateApprover(AbstractModel):
 0：企业
 1：个人
 3：企业静默签署
-注：类型为3（企业静默签署）时，此接口会默认完成该签署方的签署。
+注：类型为3（企业静默签署）时，此接口会默认完成该签署方的签署。静默签署仅进行盖章操作，不能自动签名。
         :type ApproverType: int
         :param OrganizationName: 如果签署方为企业，需要填入企业全称
         :type OrganizationName: str
@@ -1671,10 +1924,16 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         :type IsFullText: bool
         :param PreReadTime: 签署前置条件：阅读时长限制，默认为不需要
         :type PreReadTime: int
-        :param UserId: 签署方经办人的用户ID,和签署方经办人姓名+手机号+证件必须有一个
+        :param UserId: 签署方经办人的用户ID,和签署方经办人姓名+手机号+证件必须有一个。非企微场景不使用此字段
         :type UserId: str
         :param Required: 当前只支持true，默认为true
         :type Required: bool
+        :param ApproverSource: 签署人用户来源,企微侧用户请传入：WEWORKAPP
+        :type ApproverSource: str
+        :param CustomApproverTag: 客户自定义签署人标识，64位长度，保证唯一。非企微场景不使用此字段
+        :type CustomApproverTag: str
+        :param RegisterInfo: 快速注册相关信息，目前暂未开放！
+        :type RegisterInfo: :class:`tencentcloud.ess.v20201111.models.RegisterInfo`
         """
         self.ApproverType = None
         self.OrganizationName = None
@@ -1689,6 +1948,9 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         self.PreReadTime = None
         self.UserId = None
         self.Required = None
+        self.ApproverSource = None
+        self.CustomApproverTag = None
+        self.RegisterInfo = None
 
 
     def _deserialize(self, params):
@@ -1705,6 +1967,77 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         self.PreReadTime = params.get("PreReadTime")
         self.UserId = params.get("UserId")
         self.Required = params.get("Required")
+        self.ApproverSource = params.get("ApproverSource")
+        self.CustomApproverTag = params.get("CustomApproverTag")
+        if params.get("RegisterInfo") is not None:
+            self.RegisterInfo = RegisterInfo()
+            self.RegisterInfo._deserialize(params.get("RegisterInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class FlowDetailInfo(AbstractModel):
+    """此结构体(FlowDetailInfo)描述的是合同(流程)的详细信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FlowId: 合同(流程)的Id
+        :type FlowId: str
+        :param FlowName: 合同(流程)的名字
+        :type FlowName: str
+        :param FlowType: 合同(流程)的类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlowType: str
+        :param FlowStatus: 合同(流程)的状态
+1：未签署
+2：部分签署
+3：已退回
+4：完成签署
+5：已过期
+6：已取消
+        :type FlowStatus: int
+        :param FlowMessage: 合同(流程)的信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlowMessage: str
+        :param FlowDescription: 流程的描述
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlowDescription: str
+        :param CreatedOn: 合同(流程)的创建时间戳
+        :type CreatedOn: int
+        :param FlowApproverInfos: 合同(流程)的签署人数组
+        :type FlowApproverInfos: list of FlowApproverDetail
+        """
+        self.FlowId = None
+        self.FlowName = None
+        self.FlowType = None
+        self.FlowStatus = None
+        self.FlowMessage = None
+        self.FlowDescription = None
+        self.CreatedOn = None
+        self.FlowApproverInfos = None
+
+
+    def _deserialize(self, params):
+        self.FlowId = params.get("FlowId")
+        self.FlowName = params.get("FlowName")
+        self.FlowType = params.get("FlowType")
+        self.FlowStatus = params.get("FlowStatus")
+        self.FlowMessage = params.get("FlowMessage")
+        self.FlowDescription = params.get("FlowDescription")
+        self.CreatedOn = params.get("CreatedOn")
+        if params.get("FlowApproverInfos") is not None:
+            self.FlowApproverInfos = []
+            for item in params.get("FlowApproverInfos"):
+                obj = FlowApproverDetail()
+                obj._deserialize(item)
+                self.FlowApproverInfos.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1951,6 +2284,34 @@ class Recipient(AbstractModel):
         
 
 
+class RegisterInfo(AbstractModel):
+    """发起流程快速注册相关信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param LegalName: 法人姓名
+        :type LegalName: str
+        :param Uscc: 社会统一信用代码
+        :type Uscc: str
+        """
+        self.LegalName = None
+        self.Uscc = None
+
+
+    def _deserialize(self, params):
+        self.LegalName = params.get("LegalName")
+        self.Uscc = params.get("Uscc")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SignQrCode(AbstractModel):
     """一码多扫签署二维码对象
 
@@ -2218,7 +2579,7 @@ class UploadFilesRequest(AbstractModel):
         :type Caller: :class:`tencentcloud.ess.v20201111.models.Caller`
         :param FileInfos: 上传文件内容数组，最多支持20个文件
         :type FileInfos: list of UploadFile
-        :param FileUrls: 上传文件链接数组，最多支持20个URL
+        :param FileUrls: 不再使用，上传文件链接数组，最多支持20个URL
         :type FileUrls: str
         :param CoverRect: 此参数只对 PDF 文件有效。是否将pdf灰色矩阵置白
 true--是，处理置白
